function [S, M, H, C, I, R, D, tmod, Smod, Mmod, Hmod, Cmod, Imod, Rmod, Dmod, HCmod, fullR]=...
    myEstimator_2(country, k, kbacklog, modelbackstart, delta, gIF, backlog, timespan, lastdayused, H0fact, startC)
% 
% this is the full model estimator that does all the steps.
% Version with fixed detection rate
%
% Input:
% 
% country: string as from getGoronaCountryList.m, used in GetCoronaData.m
% k : parameter for the k-day rule, deaths and recoverise decided on day
%     k+1 after registration
% modelbackstart : number of days the model goes back behind the latest
%                  possible day, set = 0 for latest prediction
% gIF :            Infection fatality rate from the literature
% gIR :            Infection recovery rate, from the literature
%                  or by estimation
% backlog :        if constants are estimated from time series, use the 
%                  latest backlog+1 values
% timespan :       the number of days for prediction. The model runs up to
%                  day latest-modelstart+timespan
%
% n0=datenum('22-jan-2020');
disp('Starting full model estimation')
timespan=timespan+modelbackstart; % the absolute timespan used later
% fetch raw Johns Hopkins data
% [tC, C, tI, I, tR, R, tD, D, tER, ER]=getCIRD(country, lastdayused, k, kbacklog);
% [tC, C, tI, I, tR, R, tD, D, tER, ER]=getCIRD(country, lastdayused, k, kbacklog);
[tCr, Cr, tIr, Ir, tRr, Rr, tDr, Dr, tERr, ERr]=getCIRDrepaired(country, lastdayused, k, kbacklog);
% [tCr, Cr, tIr, Ir, tRr, Rr, tDr, Dr, tERr, ERr]=getCIRD(country, lastdayused, k, kbacklog);
C=Cr;
D=Dr;
R=Rr;
I=C-R-D;
pars=GetCoronaParameters(country);   
% this gives the actual day until values are available:
len=length(C)
% but we eventually go back for testing the model
modelstart=len-modelbackstart;
% get population size
N=pars(2);
% 
% calculation range
tr=(pars(1):lastdayused)';

% calculate differences
dI=zeros(size(I));
dC=zeros(size(C));
dI(2:end)=I(2:end)-I(1:end-1);
dC(2:end)=C(2:end)-C(1:end-1);
% avoid division by zero
tt=find(I>=1);
% now calculate as in paper
gamJH=zeros(size(C));
bJH=zeros(size(C));
gamJH(tt)=(dC(tt)-dI(tt))./I(tt);
bJH(tt)=dC(tt)./I(tt);
ttr=intersect(find(bJH>0),intersect(tt, find(gamJH>0)));
rJH(ttr)=bJH(ttr)./gamJH(ttr);
ttr=intersect(ttr, tr);
figure
plot(ttr,min(5,rJH(ttr)))
title('R_0 estimate by JH model')
figure
plot(ttr,bJH(ttr))
title('b estimate by JH model')
figure
plot(ttr,gamJH(ttr))
title('gamma estimate by JH model')
% now the Johns Hopkins data are ready, we estimate constants
% but for estimation, we use smoothed data
%
% [bCRD, gammaCRD, r0est, gCRts, gCDts]=getEstimatesFromJohnsHopkins(CS, RS, DS);
[giCRseries, giCDseries]=getDRRatesFromJohnsHopkins(Cr, Rr, Dr);
figure
plot(tr,giCRseries(tr))
title('giCRseries')
figure
plot(tr, giCDseries(tr))
title('giCDseries')
modelstart
% % and estimate constants out of time series, only up to modelstart
% gCRfinal=backestimate(max(0,gCRseries(1:modelstart)), backlog)
% gCDfinal=backestimate(max(0,gCDseries(1:modelstart)), backlog)
% gCRstart=backestimate(max(0,gCRseries(pars(1):pars(1)+kbacklog)), backlog)
% gCDstart=backestimate(max(0,gCDseries(pars(1):pars(1)+kbacklog)), backlog)
% % 
% now estimate the case fatality
% This implies another call to estimateRecovered, on smoothed data
% but now we use series: 
pars(1)
gCFseries=estimate_gCF_series(Cr, Dr, Rr, k, pars(1), lastdayused);
% here is the major change for September: 
% gIFseries=min(max(gIF,0.04*gCFseries),0.5*gCFseries);
gIFseries=gIF*(1-exp(-delta*gCFseries/gIF));
figure
plot(tr, gCFseries(tr))
title('gCFseries')
figure
plot(tr, gIFseries(tr))
title('gIFseries')
giIRseries=(1-gIFseries).*giCRseries./(1-gCFseries);
figure
plot(tr, giIRseries(tr))
title('giIRseries')
Dseries=gIFseries./gCFseries;
deltastart=Dseries(min(find(gCFseries>0)))
% figure
% plot(tr, Dseries(tr))
% title('Detection rate')
gCFfinal =backestimate(gCFseries,  backlog)
giCRfinal=backestimate(giCRseries, backlog)
giCDfinal=backestimate(giCDseries, backlog)
% now use the series for calibration
SMH=calibrateSMH_series_2(C, R, D, N , gCFseries, gIFseries, H0fact, giIRseries, k, lastdayused, backlog);
deltafinal=gIFseries(lastdayused)/gCFseries(lastdayused)
% [SMH SMHold]
% pause
S=SMH(:,1);
M=SMH(:,2);
H=SMH(:,3);
CH=(C+H);
CH=CH(tr);
SS=S(tr);
MM=M(tr);
CHSmax=max(max(CH),max(SS));
CHMmax=max(max(CH),max(MM));
SMmax=max(max(SS),max(MM));
figure
plot(CH/CHSmax,-SS/CHSmax)
axis equal
% axis square
title('-S as function of C+H, normalized')
valderSCH=myderivativechecker(CH, -S, 14, 1)
% then get gamma beta b timeseries, not smoothed as well
[bet, gam, b, ttt]=getbetagammafromSMHCN_2(S, M, H, C, N, gCFseries, gIFseries, giIRseries);
% and extract the constants using the standard backlog
fullbet=backestimate(bet(ttt), backlog)
JHb=backestimate(bJH(ttr),backlog)
fullgam=backestimate(gam(ttt), backlog)  
JHgam=backestimate(gamJH(ttr),backlog)
fullR=fullbet/fullgam
JHr=JHb/JHgam
disp(sprintf('Peak condition: 1 > %g > %g', S(modelstart)/N, 1/fullR)) 

tttr=intersect(ttt,ttr);
figure
plot(tttr,bet(tttr)./gam(tttr),tttr,rJH(tttr))
title('Estimated R for full model and JH model')
legend('R for full model','R for JH model')

% 
% now prepare the full model run, forget history
%
I=C-R-D;
SMHCIRDstart=zeros(7,1);
SMHCIRDstart(1,1)=S(modelstart);
SMHCIRDstart(2,1)=M(modelstart);
SMHCIRDstart(3,1)=H(modelstart);
SMHCIRDstart(4,1)=C(modelstart);
SMHCIRDstart(5,1)=I(modelstart);
SMHCIRDstart(6,1)=R(modelstart);
SMHCIRDstart(7,1)=D(modelstart);
% and run it
SMHCIRD=runSMHCIRD_2(SMHCIRDstart, deltafinal, giCRfinal, giCDfinal, gCFfinal, N, fullbet, fullgam, timespan);
% SMHCIRD=runSMHCIRD(SMHCIRDstart, gIF, giCR, giCD, gCF, N, beta, gamma, timespan)

% the times for plotting the prediction
tmod=(modelstart:modelstart+timespan-1)';
% extract results for notational convenience
Smod=SMHCIRD(:,1);
Mmod=SMHCIRD(:,2);
Hmod=SMHCIRD(:,3);
Cmod=SMHCIRD(:,4);
Imod=SMHCIRD(:,5);
Rmod=SMHCIRD(:,6);
Dmod=SMHCIRD(:,7);
HCmod=Cmod+Hmod;
Imax=modelstart+find(Imod==max(Imod))
Imaxval=max(Imod)
Mmax=modelstart+find(Mmod==max(Mmod))
Mmaxval=max(Mmod)
Dmax=modelstart+find(Dmod==max(Dmod))
Dmaxval=max(Dmod)
nzzz0=datenum('22-jan-2020');
Imaxdat=datestr(nzzz0+Imax)
Mmaxdat=datestr(nzzz0+Mmax)
Dmaxdat=char(datestr(nzzz0+Dmax))
disp(sprintf('%s & %5.2f  &  %5.2f  &  %5.2f  &  %5.2f  &      %5.2f        & %d  &   %d &      %s',...
    country,       fullR,    JHr,  valderSCH, deltastart, deltafinal, floor(Dmaxval), floor(Imaxval), Imaxdat))
disp('Finishing full model estimation')

